@@ -429,6 +429,7 @@ def test_mean_by_window(eng):
     test4 = data.mean_by_window(indices=[3], window=4).toarray()
     assert allclose(test4, [1, 2, 3, 4])
 
+
 def test_reshape(eng):
     original =  fromarray(arange(72).reshape(6, 6, 2), engine=eng)
     arr = original.toarray()
@@ -444,3 +445,17 @@ def test_reshape(eng):
     # cannot change length of series
     with pytest.raises(ValueError):
         original.reshape(6, 3, 4)
+
+
+def test_downsample(eng):
+    data = fromlist([arange(8)], engine=eng)
+    vals = data.downsample(2).toarray()
+    assert allclose(vals, [0.5, 2.5, 4.5, 6.5])
+    vals = data.downsample(4).toarray()
+    assert allclose(vals, [1.5, 5.5])
+
+
+def test_downsample_uneven(eng):
+    data = fromlist([arange(9)], engine=eng)
+    vals = data.downsample(2).toarray()
+    assert allclose(vals, [0.5, 2.5, 4.5, 6.5])
\ No newline at end of file
